import { useRef, useState, useCallback, useEffect } from 'react';
import ResizeObserver from 'resize-observer-polyfill';

function useWindowWidth() {
  var isMounted = useRef(true);
  var isSsr = typeof window === 'undefined';

  var _useState = useState(isSsr ? 0 : window.innerWidth),
      width = _useState[0],
      setWidth = _useState[1];

  var handleResize = useCallback(function () {
    if (isMounted.current) {
      setWidth(window.innerWidth);
    }
  }, [setWidth]);
  useEffect(function () {
    var observer = new ResizeObserver(handleResize);
    var element = window.document.querySelector('html');
    if (!element) return;
    observer.observe(element);
    return function () {
      isMounted.current = false;
      if (!element) return;
      observer.unobserve(element);
    };
  }, [handleResize]);
  return width;
}

export default useWindowWidth;
//# sourceMappingURL=react-hook-use-window-width.esm.js.map
